@@ -238,7 +238,7 @@ GroupStatusEditor::GroupStatusEditor(const QModelIndex &index, QWidget *parent)
     m_stopBt->setChecked(true);
 
     m_layout->addStretch();
-    m_layout->setMargin(1);
+    m_layout->setContentsMargins(1, 1, 1, 1);
 
     connect(m_startBt, &GroupStatusButton::toggled, this, &GroupStatusEditor::slotStatusChanged);
 }
@@ -390,7 +390,7 @@ void TransfersViewDelegate::paint(QPainter * painter, const QStyleOptionViewItem
             int progress = transferHandler->percent();
             if (progress >= 0 && progress <= 100) {
                 progressBarOption.progress = progress;
-                progressBarOption.text = QString().sprintf("%d%%", progressBarOption.progress);
+                progressBarOption.text = QStringLiteral("%1%%").arg(progressBarOption.progress);
             } else {
                 progressBarOption.text = i18nc("not available", "n/a");
             }
